@@ -103,7 +103,8 @@ class Log(object):
 
     def __init__(self, pkm: PKMClient, project: str,
                  tool: str, status: str = "",
-                 details: dict = {}, nature: str = "Execution report"):
+                 details: dict = {}, nature: str = "Execution report",
+                 max_msg_len = 80):
         self.pkm = pkm
         self.project = project
         # tool name/tag
@@ -111,6 +112,9 @@ class Log(object):
         # Proof report, Modeling report, Testing report, GUI report,
         # NER report, Summarization report, etc.
         self.nature_of_report = nature
+        # Messages longer than max_msg_len will be truncated. No truncation if
+        # None
+        self.max_msg_len = max_msg_len
         # start running time
         self.start_running_time = str(datetime.now())
         # end running time
@@ -129,15 +133,19 @@ class Log(object):
             print(f"Logging {self.json()} failed with {status}: {result}",
                   file=sys.stderr)
 
+    def _log_to(self, msg: str, dest: list):
+        dest.append(msg if self.max_msg_len is None
+                    else msg[:self.max_msg_len]+"…")
+
     def message(self, msg: str):
-        self.messages.append(msg)
+        self._log_to(msg, self.messages)
 
     def error(self, msg: str):
         self.status = False
-        self.errors.append(msg)
+        self._log_to(msg, self.errors)
 
     def warn(self, msg: str):
-        self.warnings.append(msg)
+        self._log_to(msg, self.warnings)
 
     def json(self):
         log_object = {
